@@ -68,29 +68,13 @@ def _check_event(
             AlertCondition.FILTER_COUNT_CHANGED,
             AlertCondition.FILTER_COUNT_AT_LEAST,
             AlertCondition.SEVERITY_AT_LEAST,
+            AlertCondition.SEVERITY_CHANGED,
         ):
             raise InvalidArgument(
                 "Invalid condition {} for event {}".format(
                     condition.name, event.name
                 )
             )
-        if method not in (
-            AlertMethod.SCP,
-            AlertMethod.SEND,
-            AlertMethod.SMB,
-            AlertMethod.SNMP,
-            AlertMethod.SYSLOG,
-            AlertMethod.EMAIL,
-            AlertMethod.START_TASK,
-            AlertMethod.HTTP_GET,
-            AlertMethod.SOURCEFIRE_CONNECTOR,
-            AlertMethod.VERINICE_CONNECTOR,
-            AlertMethod.TIPPINGPOINT,
-            AlertMethod.ALEMBA_VFIRE,
-        ):
-            raise InvalidArgument(
-                "Invalid method {} for event {}".format(method.name, event.name)
-            )
     elif event in (
         AlertEvent.NEW_SECINFO_ARRIVED,
         AlertEvent.UPDATED_SECINFO_ARRIVED,
@@ -105,7 +89,7 @@ def _check_event(
                 "method is required for event {}".format(event.name)
             )
 
-        if condition not in (AlertCondition.ALWAYS,):
+        if condition != AlertCondition.ALWAYS:
             raise InvalidArgument(
                 "Invalid condition {} for event {}".format(
                     condition.name, event.name
@@ -122,6 +106,34 @@ def _check_event(
             raise InvalidArgument(
                 "Invalid method {} for event {}".format(method.name, event.name)
             )
+    elif event in (
+        AlertEvent.TICKET_RECEIVED,
+        AlertEvent.OWNED_TICKET_CHANGED,
+        AlertEvent.ASSIGNED_TICKET_CHANGED,
+    ):
+        if not condition:
+            raise RequiredArgument(
+                "condition is required for event {}".format(event.name)
+            )
+
+        if not method:
+            raise RequiredArgument(
+                "method is required for event {}".format(event.name)
+            )
+        if condition != AlertCondition.ALWAYS:
+            raise InvalidArgument(
+                "Invalid condition {} for event {}".format(
+                    condition.name, event.name
+                )
+            )
+        if method not in (
+            AlertMethod.EMAIL,
+            AlertMethod.START_TASK,
+            AlertMethod.SYSLOG,
+        ):
+            raise InvalidArgument(
+                "Invalid method {} for event {}".format(method.name, event.name)
+            )
     elif event is not None:
         raise InvalidArgument('Invalid event "{}"'.format(event.name))
 
@@ -310,12 +322,15 @@ class GmpV9Mixin(GvmProtocol):
             preferences=preferences,
         )
 
-    def create_config(self, config_id: str, name: str) -> Any:
+    def create_config(
+        self, config_id: str, name: str, *, comment: Optional[str] = None
+    ) -> Any:
         """Create a new scan config
 
         Arguments:
             config_id: UUID of the existing scan config
             name: Name of the new scan config
+            comment: A comment on the config
 
         Returns:
             The response. See :py:meth:`send_command` for details.
@@ -323,17 +338,45 @@ class GmpV9Mixin(GvmProtocol):
         return self.__create_config(
             config_id=config_id,
             name=name,
+            comment=comment,
             usage_type=UsageType.SCAN,
             function=self.create_config.__name__,
         )
 
-    def create_policy(self, name: str, *, policy_id: str = None) -> Any:
+    def create_config_from_osp_scanner(
+        self, scanner_id: str, name: str, *, comment: Optional[str] = None
+    ) -> Any:
+        """Create a new scan config from an ospd scanner.
+
+        Create config by retrieving the expected preferences from the given
+        scanner via OSP.
+
+        Arguments:
+            scanner_id: UUID of an OSP scanner to get config data from
+            name: Name of the new scan config
+            comment: A comment on the config
+
+        Returns:
+            The response. See :py:meth:`send_command` for details.
+        """
+        return self.__create_config_from_osp_scanner(
+            scanner_id=scanner_id,
+            name=name,
+            comment=comment,
+            usage_type=UsageType.SCAN,
+            function=self.create_config.__name__,
+        )
+
+    def create_policy(
+        self, name: str, *, policy_id: str = None, comment: Optional[str] = None
+    ) -> Any:
         """Create a new policy config
 
         Arguments:
             name: Name of the new policy
             policy_id: UUID of an existing policy as base. By default the empty
                 policy is used.
+            comment: A comment on the policy
 
         Returns:
             The response. See :py:meth:`send_command` for details.
@@ -343,6 +386,7 @@ class GmpV9Mixin(GvmProtocol):
         return self.__create_config(
             config_id=policy_id,
             name=name,
+            comment=comment,
             usage_type=UsageType.POLICY,
             function=self.create_policy.__name__,
         )
@@ -449,7 +493,8 @@ class GmpV9Mixin(GvmProtocol):
         *,
         filter: Optional[str] = None,
         filter_id: Optional[str] = None,
-        include_certificate_data: Optional[bool] = None
+        include_certificate_data: Optional[bool] = None,
+        details: Optional[bool] = None
     ) -> Any:
         """Request a list of TLS certificates
 
@@ -467,6 +512,9 @@ class GmpV9Mixin(GvmProtocol):
 
         _add_filter(cmd, filter, filter_id)
 
+        if details is not None:
+            cmd.set_attribute("details", _to_bool(details))
+
         if include_certificate_data is not None:
             cmd.set_attribute(
                 "include_certificate_data", _to_bool(include_certificate_data)
@@ -495,6 +543,10 @@ class GmpV9Mixin(GvmProtocol):
 
         # for single tls certificate always request cert data
         cmd.set_attribute("include_certificate_data", "1")
+
+        # for single entity always request all details
+        cmd.set_attribute("details", "1")
+
         return self._send_xml_command(cmd)
 
     def modify_alert(
@@ -1043,7 +1095,13 @@ class GmpV9Mixin(GvmProtocol):
         return self._send_xml_command(cmd)
 
     def __create_config(
-        self, config_id: str, name: str, usage_type: UsageType, function: str
+        self,
+        config_id: str,
+        name: str,
+        usage_type: UsageType,
+        function: str,
+        *,
+        comment: Optional[str] = None
     ) -> Any:
         if not name:
             raise RequiredArgument(function=function, argument='name')
@@ -1052,11 +1110,36 @@ class GmpV9Mixin(GvmProtocol):
             raise RequiredArgument(function=function, argument='config_id')
 
         cmd = XmlCommand("create_config")
+        if comment is not None:
+            cmd.add_element("comment", comment)
         cmd.add_element("copy", config_id)
         cmd.add_element("name", name)
         cmd.add_element("usage_type", usage_type.value)
         return self._send_xml_command(cmd)
 
+    def __create_config_from_osp_scanner(
+        self,
+        scanner_id: str,
+        name: str,
+        usage_type: UsageType,
+        function: str,
+        *,
+        comment: Optional[str] = None
+    ) -> Any:
+        if not name:
+            raise RequiredArgument(function=function, argument='name')
+
+        if not scanner_id:
+            raise RequiredArgument(function=function, argument='scanner_id')
+
+        cmd = XmlCommand("create_config")
+        if comment is not None:
+            cmd.add_element("comment", comment)
+        cmd.add_element("scanner", scanner_id)
+        cmd.add_element("name", name)
+        cmd.add_element("usage_type", usage_type.value)
+        return self._send_xml_command(cmd)
+
     def __get_configs(
         self,
         usage_type: UsageType,
