@@ -54,6 +54,12 @@ class Gmpv208CreateConfigTestCase(GmpCreateConfigTestCase, Gmpv208TestCase):
     pass
 
 
+class Gmpv208CreateConfigFromOSPScannerTestCase(
+    GmpCreateConfigFromOSPScannerTestCase, Gmpv208TestCase
+):
+    pass
+
+
 class Gmpv208CreateCredentialTestCase(
     GmpCreateCredentialTestCase, Gmpv208TestCase
 ):
@@ -160,3 +166,14 @@ class Gmpv208ModifyTLSCertificateTestCase(
     GmpModifyTLSCertificateTestCase, Gmpv208TestCase
 ):
     pass
+
+
+class Gmpv208CreateScannerTestCase(
+    GmpCreateScannerTestCase, Gmpv208TestCase
+):
+    pass
+
+class Gmpv208ModifyScannerTestCase(
+    GmpModifyScannerTestCase, Gmpv208TestCase
+):
+    pass
