@@ -60,6 +60,12 @@ class Gmpv9CreateConfigTestCase(GmpCreateConfigTestCase, Gmpv9TestCase):
     pass
 
 
+class Gmpv9CreateConfigFromOSPScannerTestCase(
+    GmpCreateConfigFromOSPScannerTestCase, Gmpv9TestCase
+):
+    pass
+
+
 class Gmpv9CreateCredentialTestCase(GmpCreateCredentialTestCase, Gmpv9TestCase):
 
     pass
@@ -184,3 +190,15 @@ class Gmpv9ModifyTLSCertificateTestCase(
     GmpModifyTLSCertificateTestCase, Gmpv9TestCase
 ):
     pass
+
+
+class Gmpv9CreateScannerTestCase(
+    GmpCreateScannerTestCase, Gmpv9TestCase
+):
+    pass
+
+
+class Gmpv9ModifyScannerTestCase(
+    GmpModifyScannerTestCase, Gmpv9TestCase
+):
+    pass
