@@ -138,10 +138,6 @@ class Gmpv9CreateRoleTestCase(GmpCreateRoleTestCase, Gmpv9TestCase):
     pass
 
 
-class Gmpv9CreateScannerTestCase(GmpCreateScannerTestCase, Gmpv9TestCase):
-    pass
-
-
 class Gmpv9CreateUserTestCase(GmpCreateUserTestCase, Gmpv9TestCase):
     pass
 
@@ -476,6 +472,12 @@ class Gmpv9ModifyConfigSetCommentTestCase(
     pass
 
 
+class Gmpv7ModifyConfigSetNameTestCase(
+    GmpModifyConfigSetNameTestCase, Gmpv9TestCase
+):
+    pass
+
+
 class Gmpv9ModifyConfigSetFamilySelectionTestCase(
     GmpModifyConfigSetFamilySelectionTestCase, Gmpv9TestCase
 ):
@@ -526,10 +528,6 @@ class Gmpv9ModifyRoleTestCase(GmpModifyRoleTestCase, Gmpv9TestCase):
     pass
 
 
-class Gmpv9ModifyScannerTestCase(GmpModifyScannerTestCase, Gmpv9TestCase):
-    pass
-
-
 class Gmpv9ModifySettingTestCase(GmpModifySettingTestCase, Gmpv9TestCase):
     pass
 
