@@ -26,6 +26,9 @@ from .test_clone_tls_certificate import GmpCloneTLSCertificateTestCase
 from .test_create_audit import GmpCreateAuditCommandTestCase
 from .test_create_alert import GmpCreateAlertTestCase
 from .test_create_config import GmpCreateConfigTestCase
+from .test_create_config_from_osp_scanner import (
+    GmpCreateConfigFromOSPScannerTestCase,
+)
 from .test_create_credential import GmpCreateCredentialTestCase
 from .test_create_filter import GmpCreateFilterTestCase
 from .test_create_permission import GmpCreatePermissionTestCase
@@ -55,3 +58,5 @@ from .test_modify_permission import GmpModifyPermissionTestCase
 from .test_modify_tag import GmpModifyTagTestCase
 from .test_modify_ticket import GmpModifyTicketTestCase
 from .test_modify_tls_certificate import GmpModifyTLSCertificateTestCase
+from .test_create_scanner import GmpCreateScannerTestCase
+from .test_modify_scanner import GmpModifyScannerTestCase
